@@ -30,13 +30,13 @@ realimport, builtins.__import__ = builtins.__import__, tryimport
 
 from .mputil import MpUtil, globalize
 from .subcommand import Subcommand, SubcommandParser
-from .fileutil import remove_contents, find_recursive, overwrite, get_memtmpdir
+from .fileutil import remove_contents, find_recursive, overwrite, get_memtmpdir, find
 from .decorators import static_vars
 from .eventutil import EventGenerator, Event
 from .strutil import decomment_cxx, strcompare
 from .plotutil import plot_cdf, plot_linear, plot_scatter, plot_box
 from .cacheutil import PersistentCache
-from .dockerutil import dsh
+from .dockerutil import docker_sh
 from .gitutil import git_expand
 
 builtins.__import__ = realimport
