@@ -81,7 +81,7 @@ def _func_wrapper(self_id, ret: list, arglist: List[Tuple]):
         signal.signal(signal.SIGALRM, _sighandler)
 
     for argset in arglist:
-        func, args, kwargs = argset
+        func, args, kwargs, _siz = argset
         # print('wrapper: self_id: ' + str(self_id) + ', func: ' + str(func) + ', args: ' + str(args) + ', kwargs: ' + str(kwargs))
         if self.task_timeout > 0:
             signal.alarm(self.task_timeout)
@@ -102,7 +102,7 @@ def _func_wrapper(self_id, ret: list, arglist: List[Tuple]):
                 ret.append(result)
             except Exception as e:
                 print('MpUtil error: can\'t handle results from ' + str(func) + '(' + str(args) + ', ' + str(kwargs) + '). ' + str(e))
-        count += 1
+        count += _siz
 
     return self_id, count, ret
 
@@ -117,7 +117,7 @@ class MpUtil:
     results: list
     buffer: List[List]
     id = None
-    maxchunksize: int
+    __maxchunksize: int
     task_timeout: int
     arg0: object
 
@@ -159,28 +159,48 @@ class MpUtil:
         pass
 
     def __del__(self):
-        _obj_idmap.pop(self.id)
+        if _obj_idmap:
+            _obj_idmap.pop(self.id)
 
-    def flush(self):
+    @property
+    def maxchunksize(self):
+        return self.__maxchunksize
+    
+    @maxchunksize.setter
+    def maxchunksize(self, val: int):
+        self.__maxchunksize = max(val, 1)
+
+    def __flush_once_locked(self, max_n: int = None, nonblock=False):
+        if nonblock and self.free.value == 0:
+            return False
+        while self.free.value == 0:
+            self.free_cond.wait()
         ret: list = self.buffer.pop()
-        self.pool.apply_async(LogExceptions(_func_wrapper), (self.id, ret, self.queue,), callback=_on_done)
-        self.queue = []
+        self.pool.apply_async(LogExceptions(_func_wrapper), (self.id, ret, self.queue[:self.maxchunksize],), callback=_on_done)
+        self.queue = self.queue[self.maxchunksize:]
         self.free.value -= 1
+        return True
+                
+    def _flush(self, max_n: int = None, nonblock=False, locked=False):
+        if locked:
+            while self.queue and self.__flush_once_locked(nonblock=nonblock):
+                pass
+        else:
+            with self.free.get_lock():
+                while self.queue and self.__flush_once_locked(nonblock=nonblock):
+                    pass
 
-    def schedule(self, func: callable, *args, **kwargs):
+    def flush(self, max_n: int = None, nonblock=False):
+        return self._flush(max_n=max_n, nonblock=nonblock, locked=False)
+        
+    def schedule(self, func: callable, *args, _siz: int = 1, _nonblock=False, **kwargs):
         with self.free.get_lock():
-            self.queue.append((func, args, kwargs))
-
-            if self.free.value > 0:
-                self.flush()
-                return
+            self.queue.append((func, args, kwargs, _siz))
 
             if len(self.queue) < self.maxchunksize:
                 return
 
-            while self.free.value == 0:
-                self.free_cond.wait()
-            self.flush()
+            self._flush(nonblock=_nonblock, locked=True)
 
     def wait(self):
         self.flush()
